pub struct MockPamAccessConnectorRotationAttemptsApi {
PamAccessConnectorRotationAttemptsApi_expectations: MockPamAccessConnectorRotationAttemptsApi_PamAccessConnectorRotationAttemptsApi,
}Fields
PamAccessConnectorRotationAttemptsApi_expectations: MockPamAccessConnectorRotationAttemptsApi_PamAccessConnectorRotationAttemptsApiImplementations
Sourceimpl MockPamAccessConnectorRotationAttemptsApi
impl MockPamAccessConnectorRotationAttemptsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockPamAccessConnectorRotationAttemptsApi
impl MockPamAccessConnectorRotationAttemptsApi
Sourcepub fn expect_failure(&mut self) -> &mut Expectation
pub fn expect_failure(&mut self) -> &mut Expectation
Create an Expectation for mocking the failure method
Sourcepub fn expect_get_cipher(&mut self) -> &mut Expectation
pub fn expect_get_cipher(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_cipher method
Sourcepub fn expect_put_cipher(&mut self) -> &mut Expectation
pub fn expect_put_cipher(&mut self) -> &mut Expectation
Create an Expectation for mocking the put_cipher method
Sourcepub fn expect_success(&mut self) -> &mut Expectation
pub fn expect_success(&mut self) -> &mut Expectation
Create an Expectation for mocking the success method